@@ -2,7 +2,7 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2020 - Raw Material Software Limited
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
@@ -93,13 +93,11 @@ public:
             The name has to be one of the ones listed by the AudioDeviceManager's currently
             selected device type.
             This may be the same as the input device.
-            An empty string indicates the default device.
         */
         String outputDeviceName;
 
         /** The name of the audio device used for input.
             This may be the same as the output device.
-            An empty string indicates the default device.
         */
         String inputDeviceName;
 
@@ -174,7 +172,10 @@ public:
         @param preferredSetupOptions        if this is non-null, the structure will be used as the
                                             set of preferred settings when opening the device. If you
                                             use this parameter, the preferredDefaultDeviceName
-                                            field will be ignored
+                                            field will be ignored. If you set the outputDeviceName
+                                            or inputDeviceName data members of the AudioDeviceSetup
+                                            to empty strings, then a default device will be used.
+
 
         @returns an error message if anything went wrong, or an empty string if it worked ok.
     */
@@ -219,7 +220,11 @@ public:
         settings, then tweak the appropriate fields in the AudioDeviceSetup structure,
         and pass it back into this method to apply the new settings.
 
-        @param newSetup             the settings that you'd like to use
+        @param newSetup             the settings that you'd like to use.
+                                    If you don't need an input or output device, set the
+                                    inputDeviceName or outputDeviceName data members respectively
+                                    to empty strings. Note that this behaviour differs from
+                                    the behaviour of initialise().
         @param treatAsChosenDevice  if this is true and if the device opens correctly, these new
                                     settings will be taken as having been explicitly chosen by the
                                     user, and the next time createStateXml() is called, these settings
@@ -466,18 +471,20 @@ public:
     int getXRunCount() const noexcept;
 
     //==============================================================================
-    /** Deprecated. */
+   #ifndef DOXYGEN
+    [[deprecated ("Use setMidiInputDeviceEnabled instead.")]]
     void setMidiInputEnabled (const String&, bool);
-    /** Deprecated. */
+    [[deprecated ("Use isMidiInputDeviceEnabled instead.")]]
     bool isMidiInputEnabled (const String&) const;
-    /** Deprecated. */
+    [[deprecated ("Use addMidiInputDeviceCallback instead.")]]
     void addMidiInputCallback (const String&, MidiInputCallback*);
-    /** Deprecated. */
+    [[deprecated ("Use removeMidiInputDeviceCallback instead.")]]
     void removeMidiInputCallback (const String&, MidiInputCallback*);
-    /** Deprecated. */
+    [[deprecated ("Use setDefaultMidiOutputDevice instead.")]]
     void setDefaultMidiOutput (const String&);
-    /** Deprecated. */
+    [[deprecated ("Use getDefaultMidiOutputIdentifier instead.")]]
     const String& getDefaultMidiOutputName() const noexcept  { return defaultMidiOutputDeviceInfo.name; }
+   #endif
 
 private:
     //==============================================================================
@@ -519,8 +526,12 @@ private:
     class CallbackHandler;
     std::unique_ptr<CallbackHandler> callbackHandler;
 
-    void audioDeviceIOCallbackInt (const float** inputChannelData, int totalNumInputChannels,
-                                   float** outputChannelData, int totalNumOutputChannels, int numSamples);
+    void audioDeviceIOCallbackInt (const float** inputChannelData,
+                                   int totalNumInputChannels,
+                                   float** outputChannelData,
+                                   int totalNumOutputChannels,
+                                   int numSamples,
+                                   const AudioIODeviceCallbackContext& context);
     void audioDeviceAboutToStartInt (AudioIODevice*);
     void audioDeviceStoppedInt();
     void audioDeviceErrorInt (const String&);
@@ -546,6 +557,7 @@ private:
 
     AudioIODeviceType* findType (const String& inputName, const String& outputName);
     AudioIODeviceType* findType (const String& typeName);
+    void pickCurrentDeviceTypeWithDevices();
 
     JUCE_DECLARE_NON_COPYABLE_WITH_LEAK_DETECTOR (AudioDeviceManager)
 };
