@@ -2,15 +2,15 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2020 - Raw Material Software Limited
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 6 End-User License
-   Agreement and JUCE Privacy Policy (both effective as of the 16th June 2020).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-6-licence
+   End User License Agreement: www.juce.com/juce-7-licence
    Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
@@ -35,7 +35,7 @@
 
   ID:                 juce_audio_processors
   vendor:             juce
-  version:            6.1.6
+  version:            7.0.0
   name:               JUCE audio processor classes
   description:        Classes for loading and playing VST, AU, LADSPA, or internally-generated audio processors.
   website:            http://www.juce.com/juce
@@ -94,6 +94,24 @@
  #define JUCE_PLUGINHOST_LADSPA 0
 #endif
 
+/** Config: JUCE_PLUGINHOST_LV2
+    Enables the LV2 plugin hosting classes.
+ */
+#ifndef JUCE_PLUGINHOST_LV2
+ #define JUCE_PLUGINHOST_LV2 0
+#endif
+
+/** Config: JUCE_PLUGINHOST_ARA
+    Enables the ARA plugin extension hosting classes. You will need to download the ARA SDK and specify the
+    path to it either in the Projucer, using juce_set_ara_sdk_path() in your CMake project file.
+
+    The directory can be obtained by recursively cloning https://github.com/Celemony/ARA_SDK and checking out
+    the tag releases/2.1.0.
+*/
+#ifndef JUCE_PLUGINHOST_ARA
+ #define JUCE_PLUGINHOST_ARA 0
+#endif
+
 /** Config: JUCE_CUSTOM_VST3_SDK
     If enabled, the embedded VST3 SDK in JUCE will not be added to the project and instead you should
     add the path to your custom VST3 SDK to the project's header search paths. Most users shouldn't
@@ -107,10 +125,6 @@
 // #error "You need to set either the JUCE_PLUGINHOST_AU and/or JUCE_PLUGINHOST_VST and/or JUCE_PLUGINHOST_VST3 and/or JUCE_PLUGINHOST_LADSPA flags if you're using this module!"
 #endif
 
-#if ! (defined (JUCE_SUPPORT_CARBON) || JUCE_64BIT || JUCE_IOS)
- #define JUCE_SUPPORT_CARBON 1
-#endif
-
 #ifndef JUCE_SUPPORT_LEGACY_AUDIOPROCESSOR
  #define JUCE_SUPPORT_LEGACY_AUDIOPROCESSOR 1
 #endif
@@ -118,6 +132,8 @@
 //==============================================================================
 #include "utilities/juce_VSTCallbackHandler.h"
 #include "utilities/juce_VST3ClientExtensions.h"
+#include "utilities/juce_NativeScaleFactorNotifier.h"
+#include "format_types/juce_ARACommon.h"
 #include "utilities/juce_ExtensionsVisitor.h"
 #include "processors/juce_AudioProcessorParameter.h"
 #include "processors/juce_HostedAudioProcessorParameter.h"
@@ -135,9 +151,11 @@
 #include "scanning/juce_KnownPluginList.h"
 #include "format_types/juce_AudioUnitPluginFormat.h"
 #include "format_types/juce_LADSPAPluginFormat.h"
+#include "format_types/juce_LV2PluginFormat.h"
+#include "format_types/juce_VST3PluginFormat.h"
 #include "format_types/juce_VSTMidiEventList.h"
 #include "format_types/juce_VSTPluginFormat.h"
-#include "format_types/juce_VST3PluginFormat.h"
+#include "format_types/juce_ARAHosting.h"
 #include "scanning/juce_PluginDirectoryScanner.h"
 #include "scanning/juce_PluginListComponent.h"
 #include "utilities/juce_AudioProcessorParameterWithID.h"
@@ -149,3 +167,18 @@
 #include "utilities/juce_ParameterAttachments.h"
 #include "utilities/juce_AudioProcessorValueTreeState.h"
 #include "utilities/juce_PluginHostType.h"
+#include "utilities/ARA/juce_ARA_utils.h"
+
+//==============================================================================
+// These declarations are here to avoid missing-prototype warnings in user code.
+
+// If you're implementing a plugin, you should supply a body for
+// this function in your own code.
+juce::AudioProcessor* JUCE_CALLTYPE createPluginFilter();
+
+// If you are implementing an ARA enabled plugin, you need to
+// implement this function somewhere in the codebase by returning
+// SubclassOfARADocumentControllerSpecialisation::createARAFactory<SubclassOfARADocumentControllerSpecialisation>();
+#if JucePlugin_Enable_ARA
+ const ARA::ARAFactory* JUCE_CALLTYPE createARAFactory();
+#endif
