@@ -2,17 +2,16 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2017 - ROLI Ltd.
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 5 End-User License
-   Agreement and JUCE 5 Privacy Policy (both updated and effective as of the
-   27th April 2017).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-5-licence
-   Privacy Policy: www.juce.com/juce-5-privacy-policy
+   End User License Agreement: www.juce.com/juce-7-licence
+   Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
    www.gnu.org/licenses).
@@ -27,15 +26,17 @@
 namespace juce
 {
 
-AudioParameterFloat::AudioParameterFloat (const String& idToUse, const String& nameToUse,
-                                          NormalisableRange<float> r, float def,
-                                          const String& labelToUse, Category categoryToUse,
-                                          std::function<String(float, int)> stringFromValue,
-                                          std::function<float(const String&)> valueFromString)
-   : RangedAudioParameter (idToUse, nameToUse, labelToUse, categoryToUse),
-     range (r), value (def), defaultValue (def),
-     stringFromValueFunction (stringFromValue),
-     valueFromStringFunction (valueFromString)
+AudioParameterFloat::AudioParameterFloat (const ParameterID& idToUse,
+                                          const String& nameToUse,
+                                          NormalisableRange<float> r,
+                                          float def,
+                                          const AudioParameterFloatAttributes& attributes)
+    : RangedAudioParameter (idToUse, nameToUse, attributes.getAudioProcessorParameterWithIDAttributes()),
+      range (r),
+      value (def),
+      valueDefault (def),
+      stringFromValueFunction (attributes.getStringFromValueFunction()),
+      valueFromStringFunction (attributes.getValueFromStringFunction())
 {
     if (stringFromValueFunction == nullptr)
     {
@@ -45,7 +46,7 @@ AudioParameterFloat::AudioParameterFloat (const String& idToUse, const String& n
 
             if (range.interval != 0.0f)
             {
-                if (approximatelyEqual (std::abs (range.interval - (int) range.interval), 0.0f))
+                if (approximatelyEqual (std::abs (range.interval - std::floor (range.interval)), 0.0f))
                     return 0;
 
                 auto v = std::abs (roundToInt (range.interval * pow (10, numDecimalPlaces)));
@@ -71,7 +72,7 @@ AudioParameterFloat::AudioParameterFloat (const String& idToUse, const String& n
         valueFromStringFunction = [] (const String& text) { return text.getFloatValue(); };
 }
 
-AudioParameterFloat::AudioParameterFloat (String pid, String nm, float minValue, float maxValue, float def)
+AudioParameterFloat::AudioParameterFloat (const ParameterID& pid, const String& nm, float minValue, float maxValue, float def)
    : AudioParameterFloat (pid, nm, { minValue, maxValue, 0.01f }, def)
 {
 }
@@ -86,7 +87,7 @@ AudioParameterFloat::~AudioParameterFloat()
 
 float AudioParameterFloat::getValue() const                              { return convertTo0to1 (value); }
 void AudioParameterFloat::setValue (float newValue)                      { value = convertFrom0to1 (newValue); valueChanged (get()); }
-float AudioParameterFloat::getDefaultValue() const                       { return convertTo0to1 (defaultValue); }
+float AudioParameterFloat::getDefaultValue() const                       { return convertTo0to1 (valueDefault); }
 int AudioParameterFloat::getNumSteps() const                             { return AudioProcessorParameterWithID::getNumSteps(); }
 String AudioParameterFloat::getText (float v, int length) const          { return stringFromValueFunction (convertFrom0to1 (v), length); }
 float AudioParameterFloat::getValueForText (const String& text) const    { return convertTo0to1 (valueFromStringFunction (text)); }
