@@ -2,17 +2,16 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2017 - ROLI Ltd.
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 5 End-User License
-   Agreement and JUCE 5 Privacy Policy (both updated and effective as of the
-   27th April 2017).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-5-licence
-   Privacy Policy: www.juce.com/juce-5-privacy-policy
+   End User License Agreement: www.juce.com/juce-7-licence
+   Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
    www.gnu.org/licenses).
@@ -24,24 +23,26 @@
   ==============================================================================
 */
 
+
 /*******************************************************************************
  The block below describes the properties of this module, and is read by
  the Projucer to automatically generate project code that uses it.
  For details about the syntax and how to create or use a module, see the
- JUCE Module Format.txt file.
+ JUCE Module Format.md file.
 
 
  BEGIN_JUCE_MODULE_DECLARATION
 
-  ID:               juce_cryptography
-  vendor:           juce
-  version:          5.4.5
-  name:             JUCE cryptography classes
-  description:      Classes for various basic cryptography functions, including RSA, Blowfish, MD5, SHA, etc.
-  website:          http://www.juce.com/juce
-  license:          GPL/Commercial
+  ID:                 juce_cryptography
+  vendor:             juce
+  version:            7.0.0
+  name:               JUCE cryptography classes
+  description:        Classes for various basic cryptography functions, including RSA, Blowfish, MD5, SHA, etc.
+  website:            http://www.juce.com/juce
+  license:            GPL/Commercial
+  minimumCppStandard: 14
 
-  dependencies:     juce_core
+  dependencies:       juce_core
 
  END_JUCE_MODULE_DECLARATION
 
