@@ -2,17 +2,16 @@
   ==============================================================================
 
    This file is part of the JUCE library.
-   Copyright (c) 2017 - ROLI Ltd.
+   Copyright (c) 2022 - Raw Material Software Limited
 
    JUCE is an open source library subject to commercial or open-source
    licensing.
 
-   By using JUCE, you agree to the terms of both the JUCE 5 End-User License
-   Agreement and JUCE 5 Privacy Policy (both updated and effective as of the
-   27th April 2017).
+   By using JUCE, you agree to the terms of both the JUCE 7 End-User License
+   Agreement and JUCE Privacy Policy.
 
-   End User License Agreement: www.juce.com/juce-5-licence
-   Privacy Policy: www.juce.com/juce-5-privacy-policy
+   End User License Agreement: www.juce.com/juce-7-licence
+   Privacy Policy: www.juce.com/juce-privacy-policy
 
    Or: You may also use this code under the terms of the GPL v3 (see
    www.gnu.org/licenses).
@@ -29,23 +28,24 @@
  The block below describes the properties of this module, and is read by
  the Projucer to automatically generate project code that uses it.
  For details about the syntax and how to create or use a module, see the
- JUCE Module Format.txt file.
+ JUCE Module Format.md file.
 
 
  BEGIN_JUCE_MODULE_DECLARATION
 
   ID:                 juce_graphics
   vendor:             juce
-  version:            5.4.7
+  version:            7.0.0
   name:               JUCE graphics classes
   description:        Classes for 2D vector graphics, image loading/saving, font handling, etc.
   website:            http://www.juce.com/juce
   license:            GPL/Commercial
+  minimumCppStandard: 14
 
   dependencies:       juce_events
   OSXFrameworks:      Cocoa QuartzCore
   iOSFrameworks:      CoreGraphics CoreImage CoreText QuartzCore
-  linuxPackages:      x11 xinerama xext freetype2
+  linuxPackages:      freetype2
 
  END_JUCE_MODULE_DECLARATION
 
@@ -80,7 +80,7 @@
 
 /** Config: JUCE_DISABLE_COREGRAPHICS_FONT_SMOOTHING
 
-    Setting this flag will turn off CoreGraphics font smoothing, which some people
+    Setting this flag will turn off CoreGraphics font smoothing on macOS, which some people
     find makes the text too 'fat' for their taste.
 */
 #ifndef JUCE_DISABLE_COREGRAPHICS_FONT_SMOOTHING
@@ -140,6 +140,7 @@ namespace juce
 #include "contexts/juce_GraphicsContext.h"
 #include "contexts/juce_LowLevelGraphicsContext.h"
 #include "images/juce_Image.h"
+#include "images/juce_ScaledImage.h"
 #include "colour/juce_FillType.h"
 #include "native/juce_RenderingHelpers.h"
 #include "contexts/juce_LowLevelGraphicsSoftwareRenderer.h"
